@@ -15,8 +15,13 @@ fn dev() {
     // frontend::parser::dev();
     // frontend::ast::dev();
     // codegen::html::dev();
+    let xs = frontend::run_highlighter(include_str!("../source.txt"));
+    for x in xs {
+        println!("{:#?}", x);
+    }
 }
 
 fn main() {
     cli::run_cli();
+    // dev();
 }
